--
-- Placeable Silo
-- v1.0
-- @author Mario
-- www.der-ls-treffpunkt.de
-- frei verwendbar - keine erlaubnis nötig  |  free for use - no permission needed.
-- Thanks for Script Doku!
--

SiloTipTrigger = {};

function SiloTipTrigger:onCreate(id, heap)
	local trigger = SiloTipTrigger:new(g_server ~= nil, g_client ~= nil);
	--local index = g_currentMission:addOnCreateLoadedObject(trigger);
	trigger:load(id, heap);
	trigger:register(true);
end;

function SiloTipTrigger:new(isServer, isClient, mt)
	--print("new Heap TipTrigger");
	
	if SiloTipTrigger_mt == nil then
		SiloTipTrigger_mt = Class(SiloTipTrigger, TipTrigger);
	end;
	
	if mt == nil then
		mt = SiloTipTrigger_mt;
	end;

    local self = TipTrigger:new(isServer, isClient, mt);

	--print("Heap TipTrigger created");
	return self;
end;

function SiloTipTrigger:delete()
	removeTrigger(self.triggerId);
	SiloTipTrigger:superClass().delete(self);
end;

function SiloTipTrigger:load(id, heap)
	--print("loading Heap TipTrigger");
	SiloTipTrigger:superClass().load(self,id);
	
	self.triggerId=id;
	self.heap=heap;
	--addTrigger(id, "triggerCallback", self);
	
	self.appearsOnPDA = false;
	self.isFarmTrigger = false;
	self.stationName= "Heap";
	
	self.isAreaTrigger = true;

	if self.isAreaTrigger then
		self.triggerStartId = getChildAt(self.triggerId, 0);
		self.triggerEndId = getChildAt(self.triggerId, 1);
		self.triggerWidth = Utils.getNoNil(getUserAttribute(id, "triggerWidth"), 12);
		--print("Trigger Start Id: "..self.triggerStartId..", End Id: "..self.triggerEndId..", Width: "..self.triggerWidth);
	else
		self.triggerStartId = self.triggerId;
		self.triggerWidth=3;
	end;
	
	self.allowFillFromAir=true;

	self.allowFillShovel = true;
	self.isEnabled = true;

	--print("loading Heap TipTrigger successful");
	return true;
end;

function SiloTipTrigger:updateMoving(delta)
end;

function SiloTipTrigger:updateTrailerTipping(trailer, fillDelta, fillType)
	--print("Fill Heap with "..tostring(fillDelta));
	if fillDelta < 0 then
		self.heap:setFillType(fillType);
		self.heap:setFillLevel(self.heap:getFillLevel()-fillDelta);
	end;
end;

function SiloTipTrigger:getTipInfoForTrailer(trailer, tipReferencePointIndex)
	local minDistance, bestPoint = SiloTipTrigger:superClass().getTipDistanceFromTrailer(self,trailer, tipReferencePointIndex);

	local isAllowed = false;

	local fillType=self.heap:getFillType();
	if(fillType==0)then
		local acceptedFillTypes=self.heap:getAcceptedFillTypes();
		if acceptedFillTypes[trailer.currentFillType] then
			isAllowed = true;
		end;
	elseif(fillType==trailer.currentFillType)then
		isAllowed = true;
	end;

	--print("TipInfoForTrailer: "..tostring(isAllowed)..", "..tostring(minDistance)..", "..tostring(bestPoint));
	--print("FillType in Heap is "..tostring(fillType).." and in Trailer "..tostring(trailer.currentFillType));
	return isAllowed, minDistance, bestPoint;
end;

function SiloTipTrigger:getAllowFillFromAir()
	return self.allowFillFromAir;
end;

